diff --git a/content/base/src/nsContentAreaDragDrop.cpp b/content/base/src/nsContentAreaDragDrop.cpp
index 68ada2068d9..1c3e4f02685 100644
--- a/content/base/src/nsContentAreaDragDrop.cpp
+++ b/content/base/src/nsContentAreaDragDrop.cpp
@@ -291,7 +291,7 @@ nsContentAreaDragDrop::ExtractURLFromData(const nsACString & inFlavor, nsISuppor
if ( inFlavor.Equals(kUnicodeMime) ) {
// the data is regular unicode, just go with what we get. It may be a url, it
// may not be. *shrug*
- nsCOMPtr stringData(do_QueryInterface(inDataWrapper));
+ nsCOMPtr stringData(do_QueryInterface(inDataWrapper));
if ( stringData ) {
nsXPIDLString data;
stringData->GetData(getter_Copies(data));
@@ -301,7 +301,7 @@ nsContentAreaDragDrop::ExtractURLFromData(const nsACString & inFlavor, nsISuppor
else if ( inFlavor.Equals(kURLMime) ) {
// the data is an internet shortcut of the form \n. Strip
// out the url piece and return that.
- nsCOMPtr stringData(do_QueryInterface(inDataWrapper));
+ nsCOMPtr stringData(do_QueryInterface(inDataWrapper));
if ( stringData ) {
nsXPIDLString data;
stringData->GetData(getter_Copies(data));
@@ -912,7 +912,7 @@ nsContentAreaDragDrop::CreateTransferable(const nsAString & inURLString, const n
nsAutoString dragData ( inURLString );
dragData += NS_LITERAL_STRING("\n");
dragData += inTitleString;
- nsCOMPtr urlPrimitive(do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID));
+ nsCOMPtr urlPrimitive(do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID));
if ( !urlPrimitive )
return NS_ERROR_FAILURE;
urlPrimitive->SetData(dragData.get());
@@ -920,7 +920,7 @@ nsContentAreaDragDrop::CreateTransferable(const nsAString & inURLString, const n
}
// add the full html
- nsCOMPtr htmlPrimitive(do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID));
+ nsCOMPtr htmlPrimitive(do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID));
if ( !htmlPrimitive )
return NS_ERROR_FAILURE;
htmlPrimitive->SetData(PromiseFlatString(inHTMLString).get());
@@ -929,7 +929,7 @@ nsContentAreaDragDrop::CreateTransferable(const nsAString & inURLString, const n
// add the plain (unicode) text. we use the url for text/unicode data if an anchor
// is being dragged, rather than the title text of the link or the alt text for
// an anchor image.
- nsCOMPtr textPrimitive(do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID));
+ nsCOMPtr textPrimitive(do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID));
if ( !textPrimitive )
return NS_ERROR_FAILURE;
textPrimitive->SetData(PromiseFlatString(inIsAnchor ? inURLString : inTitleString).get());
diff --git a/content/base/src/nsContentPolicy.cpp b/content/base/src/nsContentPolicy.cpp
index d84d06187a2..0ed0ad51190 100644
--- a/content/base/src/nsContentPolicy.cpp
+++ b/content/base/src/nsContentPolicy.cpp
@@ -78,7 +78,7 @@ nsContentPolicy::nsContentPolicy()
*/
nsCOMPtr item;
while (NS_SUCCEEDED(catEnum->GetNext(getter_AddRefs(item)))) {
- nsCOMPtr string = do_QueryInterface(item, &rv);
+ nsCOMPtr string = do_QueryInterface(item, &rv);
if (NS_FAILED(rv))
continue;
diff --git a/content/base/src/nsCopySupport.cpp b/content/base/src/nsCopySupport.cpp
index 746d192325a..a0fa4545d9b 100644
--- a/content/base/src/nsCopySupport.cpp
+++ b/content/base/src/nsCopySupport.cpp
@@ -195,14 +195,14 @@ nsresult nsCopySupport::HTMLCopy(nsISelection *aSel, nsIDocument *aDoc, PRInt16
}
// get wStrings to hold clip data
- nsCOMPtr dataWrapper, contextWrapper, infoWrapper;
- dataWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ nsCOMPtr dataWrapper, contextWrapper, infoWrapper;
+ dataWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(dataWrapper, NS_ERROR_FAILURE);
if (bIsHTMLCopy)
{
- contextWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ contextWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(contextWrapper, NS_ERROR_FAILURE);
- infoWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ infoWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(infoWrapper, NS_ERROR_FAILURE);
}
diff --git a/content/base/src/nsDocumentViewer.cpp b/content/base/src/nsDocumentViewer.cpp
index c33e5c39900..f3f5a1ba90e 100644
--- a/content/base/src/nsDocumentViewer.cpp
+++ b/content/base/src/nsDocumentViewer.cpp
@@ -6257,7 +6257,7 @@ DocumentViewerImpl::CheckForPrinters(nsIPrintOptions* aPrintOptions,
aPrintSettings->GetPrinterName(&defPrinterName);
if (!defPrinterName || (defPrinterName && !*defPrinterName)) {
if (defPrinterName) nsMemory::Free(defPrinterName);
- nsCOMPtr wStr = do_QueryInterface(supps);
+ nsCOMPtr wStr = do_QueryInterface(supps);
if (wStr) {
PRUnichar* defPrinterName;
wStr->ToString(&defPrinterName);
diff --git a/dom/src/base/nsDOMClassInfo.cpp b/dom/src/base/nsDOMClassInfo.cpp
index c7687bc443f..7ae810f2c5f 100644
--- a/dom/src/base/nsDOMClassInfo.cpp
+++ b/dom/src/base/nsDOMClassInfo.cpp
@@ -1133,10 +1133,10 @@ nsDOMClassInfo::RegisterExternalClasses()
nsCOMPtr entry;
while (NS_SUCCEEDED(e->GetNext(getter_AddRefs(entry)))) {
- nsCOMPtr category(do_QueryInterface(entry));
+ nsCOMPtr category(do_QueryInterface(entry));
if (!category) {
- NS_WARNING("Category entry not an nsISupportsString!");
+ NS_WARNING("Category entry not an nsISupportsCString!");
continue;
}
diff --git a/dom/src/base/nsScriptNameSpaceManager.cpp b/dom/src/base/nsScriptNameSpaceManager.cpp
index f291117b7f1..315927a3799 100644
--- a/dom/src/base/nsScriptNameSpaceManager.cpp
+++ b/dom/src/base/nsScriptNameSpaceManager.cpp
@@ -176,10 +176,10 @@ nsScriptNameSpaceManager::FillHash(nsICategoryManager *aCategoryManager,
nsCOMPtr entry;
while (NS_SUCCEEDED(e->GetNext(getter_AddRefs(entry)))) {
- nsCOMPtr category(do_QueryInterface(entry));
+ nsCOMPtr category(do_QueryInterface(entry));
if (!category) {
- NS_WARNING("Category entry not an nsISupportsString!");
+ NS_WARNING("Category entry not an nsISupportsCString!");
continue;
}
@@ -302,10 +302,10 @@ nsScriptNameSpaceManager::RegisterExternalInterfaces(PRBool aAsProto)
PRBool found_old, dom_prefix;
while (NS_SUCCEEDED(enumerator->GetNext(getter_AddRefs(entry)))) {
- nsCOMPtr category(do_QueryInterface(entry));
+ nsCOMPtr category(do_QueryInterface(entry));
if (!category) {
- NS_WARNING("Category entry not an nsISupportsString!");
+ NS_WARNING("Category entry not an nsISupportsCString!");
continue;
}
diff --git a/dom/src/build/nsScriptNameSpaceManager.cpp b/dom/src/build/nsScriptNameSpaceManager.cpp
index f291117b7f1..315927a3799 100644
--- a/dom/src/build/nsScriptNameSpaceManager.cpp
+++ b/dom/src/build/nsScriptNameSpaceManager.cpp
@@ -176,10 +176,10 @@ nsScriptNameSpaceManager::FillHash(nsICategoryManager *aCategoryManager,
nsCOMPtr entry;
while (NS_SUCCEEDED(e->GetNext(getter_AddRefs(entry)))) {
- nsCOMPtr category(do_QueryInterface(entry));
+ nsCOMPtr category(do_QueryInterface(entry));
if (!category) {
- NS_WARNING("Category entry not an nsISupportsString!");
+ NS_WARNING("Category entry not an nsISupportsCString!");
continue;
}
@@ -302,10 +302,10 @@ nsScriptNameSpaceManager::RegisterExternalInterfaces(PRBool aAsProto)
PRBool found_old, dom_prefix;
while (NS_SUCCEEDED(enumerator->GetNext(getter_AddRefs(entry)))) {
- nsCOMPtr category(do_QueryInterface(entry));
+ nsCOMPtr category(do_QueryInterface(entry));
if (!category) {
- NS_WARNING("Category entry not an nsISupportsString!");
+ NS_WARNING("Category entry not an nsISupportsCString!");
continue;
}
diff --git a/editor/libeditor/html/nsHTMLDataTransfer.cpp b/editor/libeditor/html/nsHTMLDataTransfer.cpp
index 404f5c0f673..58ba47a6a10 100644
--- a/editor/libeditor/html/nsHTMLDataTransfer.cpp
+++ b/editor/libeditor/html/nsHTMLDataTransfer.cpp
@@ -805,7 +805,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
#endif
if (flavor.Equals(NS_LITERAL_STRING(kHTMLMime)))
{
- nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
+ nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
if (textDataObj && len > 0)
{
PRUnichar* text = nsnull;
@@ -821,7 +821,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromTransferable(nsITransferable *transferable
}
else if (flavor.Equals(NS_LITERAL_STRING(kUnicodeMime)))
{
- nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
+ nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
if (textDataObj && len > 0)
{
PRUnichar* text = nsnull;
@@ -943,7 +943,7 @@ NS_IMETHODIMP nsHTMLEditor::InsertFromDrop(nsIDOMEvent* aDropEvent)
nsAutoString contextStr, infoStr;
nsCOMPtr contextDataObj, infoDataObj;
PRUint32 contextLen, infoLen;
- nsCOMPtr textDataObj;
+ nsCOMPtr textDataObj;
nsCOMPtr contextTrans = do_CreateInstance(kCTransferableCID);
NS_ENSURE_TRUE(contextTrans, NS_ERROR_NULL_POINTER);
@@ -1264,9 +1264,9 @@ NS_IMETHODIMP nsHTMLEditor::DoDrag(nsIDOMEvent *aDragEvent)
// if we have an empty string, we're done; otherwise continue
if ( !buffer.IsEmpty() )
{
- nsCOMPtr dataWrapper, contextWrapper, infoWrapper;
+ nsCOMPtr dataWrapper, contextWrapper, infoWrapper;
- dataWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ dataWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(dataWrapper, NS_ERROR_FAILURE);
rv = dataWrapper->SetData( NS_CONST_CAST(PRUnichar*, buffer.get()) );
if (NS_FAILED(rv)) return rv;
@@ -1285,9 +1285,9 @@ NS_IMETHODIMP nsHTMLEditor::DoDrag(nsIDOMEvent *aDragEvent)
}
else
{
- contextWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ contextWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(contextWrapper, NS_ERROR_FAILURE);
- infoWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ infoWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(infoWrapper, NS_ERROR_FAILURE);
contextWrapper->SetData ( NS_CONST_CAST(PRUnichar*,parents.get()) );
@@ -1367,7 +1367,7 @@ NS_IMETHODIMP nsHTMLEditor::Paste(PRInt32 aSelectionType)
nsAutoString contextStr, infoStr;
nsCOMPtr contextDataObj, infoDataObj;
PRUint32 contextLen, infoLen;
- nsCOMPtr textDataObj;
+ nsCOMPtr textDataObj;
nsCOMPtr contextTrans = do_CreateInstance(kCTransferableCID);
NS_ENSURE_TRUE(contextTrans, NS_ERROR_NULL_POINTER);
@@ -1437,9 +1437,9 @@ NS_IMETHODIMP nsHTMLEditor::CanPaste(PRInt32 aSelectionType, PRBool *aCanPaste)
// add the flavors for all editors
for (const char* const* flavor = textEditorFlavors; *flavor; flavor++)
{
- nsCOMPtr flavorString;
- nsComponentManager::CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, nsnull,
- NS_GET_IID(nsISupportsString), getter_AddRefs(flavorString));
+ nsCOMPtr flavorString;
+ nsComponentManager::CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID, nsnull,
+ NS_GET_IID(nsISupportsCString), getter_AddRefs(flavorString));
if (flavorString)
{
flavorString->SetData(*flavor);
@@ -1454,9 +1454,9 @@ NS_IMETHODIMP nsHTMLEditor::CanPaste(PRInt32 aSelectionType, PRBool *aCanPaste)
*htmlFlavor;
htmlFlavor++)
{
- nsCOMPtr flavorString;
- nsComponentManager::CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, nsnull,
- NS_GET_IID(nsISupportsString), getter_AddRefs(flavorString));
+ nsCOMPtr flavorString;
+ nsComponentManager::CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID, nsnull,
+ NS_GET_IID(nsISupportsCString), getter_AddRefs(flavorString));
if (flavorString)
{
flavorString->SetData(*htmlFlavor);
@@ -1578,7 +1578,7 @@ NS_IMETHODIMP nsHTMLEditor::PasteAsPlaintextQuotation(PRInt32 aSelectionType)
nsAutoString stuffToPaste;
if (flavor.Equals(NS_LITERAL_STRING(kUnicodeMime)))
{
- nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
+ nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
if (textDataObj && len > 0)
{
PRUnichar* text = nsnull;
diff --git a/editor/libeditor/text/nsPlaintextDataTransfer.cpp b/editor/libeditor/text/nsPlaintextDataTransfer.cpp
index 5a09cb2a28b..fed12548912 100644
--- a/editor/libeditor/text/nsPlaintextDataTransfer.cpp
+++ b/editor/libeditor/text/nsPlaintextDataTransfer.cpp
@@ -165,7 +165,7 @@ NS_IMETHODIMP nsPlaintextEditor::InsertTextFromTransferable(nsITransferable *tra
flavor.AssignWithConversion( bestFlavor ); // just so we can use flavor.Equals()
if (flavor.Equals(NS_LITERAL_STRING(kUnicodeMime)))
{
- nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
+ nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
if (textDataObj && len > 0)
{
PRUnichar* text = nsnull;
@@ -493,7 +493,7 @@ NS_IMETHODIMP nsPlaintextEditor::DoDrag(nsIDOMEvent *aDragEvent)
// if we have an empty string, we're done; otherwise continue
if ( !buffer.IsEmpty() )
{
- nsCOMPtr dataWrapper = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID);
+ nsCOMPtr dataWrapper = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID);
NS_ENSURE_TRUE(dataWrapper, NS_ERROR_FAILURE);
rv = dataWrapper->SetData( NS_CONST_CAST(PRUnichar*, buffer.get()) );
@@ -601,9 +601,9 @@ NS_IMETHODIMP nsPlaintextEditor::CanPaste(PRInt32 aSelectionType, PRBool *aCanPa
// add the flavors for text editors
for (const char* const* flavor = textEditorFlavors; *flavor; flavor++)
{
- nsCOMPtr flavorString;
- nsComponentManager::CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, nsnull,
- NS_GET_IID(nsISupportsString), getter_AddRefs(flavorString));
+ nsCOMPtr flavorString;
+ nsComponentManager::CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID, nsnull,
+ NS_GET_IID(nsISupportsCString), getter_AddRefs(flavorString));
if (flavorString)
{
flavorString->SetData(*flavor);
diff --git a/editor/libeditor/text/nsPlaintextEditor.cpp b/editor/libeditor/text/nsPlaintextEditor.cpp
index 9d38d6dae12..feacf1694b9 100644
--- a/editor/libeditor/text/nsPlaintextEditor.cpp
+++ b/editor/libeditor/text/nsPlaintextEditor.cpp
@@ -1624,7 +1624,7 @@ nsPlaintextEditor::PasteAsQuotation(PRInt32 aSelectionType)
nsAutoString stuffToPaste;
if (flavor.Equals(NS_LITERAL_STRING(kUnicodeMime)))
{
- nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
+ nsCOMPtr textDataObj ( do_QueryInterface(genericDataObj) );
if (textDataObj && len > 0)
{
PRUnichar* text = nsnull;
diff --git a/editor/ui/composer/content/editor.js b/editor/ui/composer/content/editor.js
index 0a1c06f3f76..4f6123db52a 100644
--- a/editor/ui/composer/content/editor.js
+++ b/editor/ui/composer/content/editor.js
@@ -2280,7 +2280,7 @@ function EditorSetDefaultPrefsAndDoctype()
try
{
prefAuthorString = gPrefs.getComplexValue("editor.author",
- Components.interfaces.nsISupportsWString).data;
+ Components.interfaces.nsISupportsString).data;
}
catch (ex) {}
if ( prefAuthorString && prefAuthorString != 0)
diff --git a/editor/ui/composer/content/editorUtilities.js b/editor/ui/composer/content/editorUtilities.js
index db8234d06b6..3496d769157 100644
--- a/editor/ui/composer/content/editorUtilities.js
+++ b/editor/ui/composer/content/editorUtilities.js
@@ -260,10 +260,10 @@ function SetUnicharPref(aPrefName, aPrefValue)
if (prefs)
{
try {
- var str = Components.classes["@mozilla.org/supports-wstring;1"]
- .createInstance(Components.interfaces.nsISupportsWString);
+ var str = Components.classes["@mozilla.org/supports-string;1"]
+ .createInstance(Components.interfaces.nsISupportsString);
str.data = aPrefValue;
- prefs.setComplexValue(aPrefName, Components.interfaces.nsISupportsWString, str);
+ prefs.setComplexValue(aPrefName, Components.interfaces.nsISupportsString, str);
}
catch(e) {}
}
@@ -275,7 +275,7 @@ function GetUnicharPref(aPrefName, aDefVal)
if (prefs)
{
try {
- return prefs.getComplexValue(aPrefName, Components.interfaces.nsISupportsWString).data;
+ return prefs.getComplexValue(aPrefName, Components.interfaces.nsISupportsString).data;
}
catch(e) {}
}
diff --git a/editor/ui/composer/content/publishprefs.js b/editor/ui/composer/content/publishprefs.js
index 042ed68d1a4..f558e196b56 100644
--- a/editor/ui/composer/content/publishprefs.js
+++ b/editor/ui/composer/content/publishprefs.js
@@ -764,7 +764,7 @@ function GetPublishStringPref(prefBranch, name)
if (prefBranch && name)
{
try {
- return prefBranch.getComplexValue(name, Components.interfaces.nsISupportsWString).data;
+ return prefBranch.getComplexValue(name, Components.interfaces.nsISupportsString).data;
} catch (e) {}
}
return "";
@@ -775,10 +775,10 @@ function SetPublishStringPref(prefBranch, name, value)
if (prefBranch && name)
{
try {
- var str = Components.classes["@mozilla.org/supports-wstring;1"]
- .createInstance(Components.interfaces.nsISupportsWString);
+ var str = Components.classes["@mozilla.org/supports-string;1"]
+ .createInstance(Components.interfaces.nsISupportsString);
str.data = value;
- prefBranch.setComplexValue(name, Components.interfaces.nsISupportsWString, str);
+ prefBranch.setComplexValue(name, Components.interfaces.nsISupportsString, str);
} catch (e) {}
}
}
diff --git a/embedding/components/appstartup/src/nsAppStartupNotifier.cpp b/embedding/components/appstartup/src/nsAppStartupNotifier.cpp
index b909bad8972..64c2091db05 100644
--- a/embedding/components/appstartup/src/nsAppStartupNotifier.cpp
+++ b/embedding/components/appstartup/src/nsAppStartupNotifier.cpp
@@ -72,7 +72,7 @@ NS_IMETHODIMP nsAppStartupNotifier::Observe(nsISupports *aSubject, const char *a
nsCOMPtr entry;
while (NS_SUCCEEDED(enumerator->GetNext(getter_AddRefs(entry)))) {
- nsCOMPtr category = do_QueryInterface(entry, &rv);
+ nsCOMPtr category = do_QueryInterface(entry, &rv);
if (NS_SUCCEEDED(rv)) {
nsXPIDLCString categoryEntry;
diff --git a/embedding/components/commandhandler/src/nsCommandGroup.cpp b/embedding/components/commandhandler/src/nsCommandGroup.cpp
index 71c57eef144..312bb7a0262 100644
--- a/embedding/components/commandhandler/src/nsCommandGroup.cpp
+++ b/embedding/components/commandhandler/src/nsCommandGroup.cpp
@@ -126,7 +126,7 @@ nsGroupsEnumerator::GetNext(nsISupports **_retval)
char *thisGroupName = mGroupNames[mIndex];
- nsCOMPtr supportsString = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, &rv);
+ nsCOMPtr supportsString = do_CreateInstance(NS_SUPPORTS_CSTRING_CONTRACTID, &rv);
if (NS_FAILED(rv)) return rv;
supportsString->SetData(thisGroupName);
@@ -222,7 +222,7 @@ nsNamedGroupEnumerator::GetNext(nsISupports **_retval)
PRUnichar *thisGroupName = (PRUnichar *)mGroupArray->ElementAt(mIndex);
nsresult rv;
- nsCOMPtr supportsString = do_CreateInstance(NS_SUPPORTS_WSTRING_CONTRACTID, &rv);
+ nsCOMPtr supportsString = do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, &rv);
if (NS_FAILED(rv)) return rv;
supportsString->SetData(thisGroupName);
diff --git a/embedding/components/windowwatcher/src/nsWindowWatcher.cpp b/embedding/components/windowwatcher/src/nsWindowWatcher.cpp
index 2855b070252..311ec271ee0 100644
--- a/embedding/components/windowwatcher/src/nsWindowWatcher.cpp
+++ b/embedding/components/windowwatcher/src/nsWindowWatcher.cpp
@@ -1736,8 +1736,8 @@ nsWindowWatcher::AddSupportsTojsvals(nsISupports *aArg,
argPrimitive->GetType(&type);
switch(type) {
- case nsISupportsPrimitive::TYPE_STRING : {
- nsCOMPtr p(do_QueryInterface(argPrimitive));
+ case nsISupportsPrimitive::TYPE_CSTRING : {
+ nsCOMPtr p(do_QueryInterface(argPrimitive));
NS_ENSURE_TRUE(p, NS_ERROR_UNEXPECTED);
char *data;
@@ -1751,8 +1751,8 @@ nsWindowWatcher::AddSupportsTojsvals(nsISupports *aArg,
break;
}
- case nsISupportsPrimitive::TYPE_WSTRING : {
- nsCOMPtr p(do_QueryInterface(argPrimitive));
+ case nsISupportsPrimitive::TYPE_STRING : {
+ nsCOMPtr p(do_QueryInterface(argPrimitive));
NS_ENSURE_TRUE(p, NS_ERROR_UNEXPECTED);
PRUnichar *data;
diff --git a/embedding/qa/jstests/nsIFontListTest.txt b/embedding/qa/jstests/nsIFontListTest.txt
index 8d409e7cd4c..d94b5c842d6 100644
--- a/embedding/qa/jstests/nsIFontListTest.txt
+++ b/embedding/qa/jstests/nsIFontListTest.txt
@@ -154,7 +154,7 @@ function constructFontList(fontList)
while (fontEnumerator.hasMoreElements())
{
var fontName = fontEnumerator.getNext();
- fontName = fontName.QueryInterface(Components.interfaces.nsISupportsWString);
+ fontName = fontName.QueryInterface(Components.interfaces.nsISupportsString);
var fontNameStr = fontName.toString();
if (fontEnumerator.hasMoreElements())
tempres = tempres + fontNameStr + ", ";
diff --git a/extensions/inspector/resources/content/inspector.xml b/extensions/inspector/resources/content/inspector.xml
index dd93ace0509..f80b001cc95 100644
--- a/extensions/inspector/resources/content/inspector.xml
+++ b/extensions/inspector/resources/content/inspector.xml
@@ -307,8 +307,8 @@
term collectively the nsISupports Primitives Interfaces. These
are a set of interfaces a component can support to allow automatic conversion to
and from many basic types. For example, an interface can define that it
-supports the nsISupportsString interface, and this could be used by any
+supports the nsISupportsCString interface, and this could be used by any
program that wishes to get a string representation of the object. If an
interface wishes to expose itself as a "boolean value", it may choose
to support the nsISupportsPRBool interface.
@@ -48,8 +48,8 @@ to support the nsISupportsPRBool interface.
calling), you can use
the builtin functions str(), int(), long() etc., on the
object. In the
-case of str(), if the object does not support the nsISupportsString
-or nsISupportsWString interfaces, the default string str() for the
+case of str(), if the object does not support the nsISupportsCString
+or nsISupportsString interfaces, the default string str() for the
object will be returned (i.e., what is normally returned for most XPCOM objects -
support for these interface is not very common!). In the case of the numeric functions, a ValueError
exception will be raised if the objects do not support any interface that can be
@@ -71,8 +71,8 @@ of these interfaces:
If your class does not define support for these interfaces, the framework
will use standard Python class semantics to implement them - i.e., if your
- class provides a __str__ method, it will be used to implement nsISupportsString
- and nsISupportsWString, if you provide __int__, __long__,
+ class provides a __str__ method, it will be used to implement nsISupportsCString
+ and nsISupportsString, if you provide __int__, __long__,
__float__ etc., methods, they will be used to implement the numeric
interfaces. If your class defines no such special methods, then the
QueryInterface() for those interfaces fails (rather than the QI succeeding
@@ -83,7 +83,7 @@ of these interfaces:
possible. Consider Python code that does a str() on an XPCOM
interface, and where the XPCOM interface itself is implemented in Python and
provides a __str__ method. The str() on the original
-interface queries for the nsISupportsString interface. The
+interface queries for the nsISupportsCString interface. The
Python implemented object responds to this interface and delegates to the __str__
method. At the end of all this, str() returns the same result
as if the objects were native Python objects with no XPCOM layer in between.
diff --git a/extensions/python/xpcom/server/policy.py b/extensions/python/xpcom/server/policy.py
index 15892984c15..12fb4ff24fd 100644
--- a/extensions/python/xpcom/server/policy.py
+++ b/extensions/python/xpcom/server/policy.py
@@ -294,8 +294,8 @@ class DefaultPolicy:
return self._doHandleException(name, exc_info)
_supports_primitives_data_ = [
+ ("nsISupportsCString", "__str__", str),
("nsISupportsString", "__str__", str),
- ("nsISupportsWString", "__str__", str),
("nsISupportsPRUint64", "__long__", long),
("nsISupportsPRInt64", "__long__", long),
("nsISupportsPRUint32", "__int__", int),
diff --git a/extensions/python/xpcom/src/TypeObject.cpp b/extensions/python/xpcom/src/TypeObject.cpp
index 53016e88123..a710e788950 100644
--- a/extensions/python/xpcom/src/TypeObject.cpp
+++ b/extensions/python/xpcom/src/TypeObject.cpp
@@ -143,7 +143,7 @@ PyXPCOM_TypeObject::Py_str(PyObject *self)
char *val = NULL;
Py_BEGIN_ALLOW_THREADS;
{ // scope to kill pointer while thread-lock released.
- nsCOMPtr ss( do_QueryInterface(pis->m_obj, &rv ));
+ nsCOMPtr ss( do_QueryInterface(pis->m_obj, &rv ));
if (NS_SUCCEEDED(rv))
rv = ss->ToString(&val);
} // end-scope
diff --git a/extensions/python/xpcom/src/xpcom.cpp b/extensions/python/xpcom/src/xpcom.cpp
index 48f9143d8af..244fc42f7e3 100644
--- a/extensions/python/xpcom/src/xpcom.cpp
+++ b/extensions/python/xpcom/src/xpcom.cpp
@@ -579,7 +579,7 @@ init_xpcom() {
Py_XDECREF(obFuncPtr);
REGISTER_IID(nsISupports);
- REGISTER_IID(nsISupportsString);
+ REGISTER_IID(nsISupportsCString);
REGISTER_IID(nsIModule);
REGISTER_IID(nsIFactory);
REGISTER_IID(nsIWeakReference);
diff --git a/extensions/xml-rpc/idl/nsIXmlRpcClient.idl b/extensions/xml-rpc/idl/nsIXmlRpcClient.idl
index efcc00d8282..30c90d1d9d2 100644
--- a/extensions/xml-rpc/idl/nsIXmlRpcClient.idl
+++ b/extensions/xml-rpc/idl/nsIXmlRpcClient.idl
@@ -18,9 +18,9 @@
/*
* XPCOM XML-RPC Client, interface definition.
- * Version: $Revision: 1.4 $
+ * Version: $Revision: 1.5 $
*
- * $Id: nsIXmlRpcClient.idl,v 1.4 2002-02-12 23:57:08 samuel%sieb.net Exp $
+ * $Id: nsIXmlRpcClient.idl,v 1.5 2002-08-06 00:52:08 alecf%netscape.com Exp $
*/
#include "nsISupports.idl"
@@ -69,7 +69,7 @@ interface nsIXmlRpcClient: nsISupports {
* nsISupportsPRUint8, nsISupportsPRUint16,
* nsISupportsPRInt16, nsISupportsPRInt32:
* nsISupportsPRBool:
- * nsISupportsChar, nsISupportsString:
+ * nsISupportsChar, nsISupportsCString:
* nsISupportsFloat, nsISupportsDouble:
* nsISupportsPRTime:
* nsIInputStream:
@@ -82,10 +82,10 @@ interface nsIXmlRpcClient: nsISupports {
* Return value will be converted as follows:
* or : nsISupportsPRInt32
* : nsISupportsPRBool
- * : nsISupportsString
+ * : nsISupportsCString
* : nsISupportsDouble
* : nsISupportsPRTime
- * : nsISupportsString
+ * : nsISupportsCString
* : nsISupportsArray
* : nsIDictionary
*
@@ -144,7 +144,7 @@ interface nsIXmlRpcClient: nsISupports {
[iid_is(uuid),retval] out nsQIResult result);
const unsigned long INT = 1; // nsISupportsPRInt32
const unsigned long BOOLEAN = 2; // nsISupportsPRBool
- const unsigned long STRING = 3; // nsISupportsString
+ const unsigned long STRING = 3; // nsISupportsCString
const unsigned long DOUBLE = 4; // nsISupportsDouble
const unsigned long DATETIME = 5; // nsISupportsPRTime
const unsigned long ARRAY = 6; // nsISupportsArray
diff --git a/extensions/xml-rpc/src/nsXmlRpcClient.js b/extensions/xml-rpc/src/nsXmlRpcClient.js
index 09766cb099c..6336304ff9f 100644
--- a/extensions/xml-rpc/src/nsXmlRpcClient.js
+++ b/extensions/xml-rpc/src/nsXmlRpcClient.js
@@ -20,9 +20,9 @@
/*
* nsXmlRpcClient XPCOM component
- * Version: $Revision: 1.26 $
+ * Version: $Revision: 1.27 $
*
- * $Id: nsXmlRpcClient.js,v 1.26 2002-06-16 06:17:54 samuel%sieb.net Exp $
+ * $Id: nsXmlRpcClient.js,v 1.27 2002-08-06 00:52:09 alecf%netscape.com Exp $
*/
/*
@@ -360,9 +360,9 @@ nsXmlRpcClient.prototype = {
'nsISupportsPRBool');
case this.STRING:
- uuid.value = Components.interfaces.nsISupportsString
+ uuid.value = Components.interfaces.nsISupportsCString
return createInstance(SUPPORTSID + 'string;1',
- 'nsISupportsString');
+ 'nsISupportsCString');
case this.DOUBLE:
uuid.value = Components.interfaces.nsISupportsDouble
@@ -585,7 +585,7 @@ nsXmlRpcClient.prototype = {
} catch(e) {}
try {
- obj.QueryInterface(Components.interfaces.nsISupportsString);
+ obj.QueryInterface(Components.interfaces.nsISupportsCString);
return 'String';
} catch(e) {}
diff --git a/extensions/xml-rpc/test/xml-rpc.xul b/extensions/xml-rpc/test/xml-rpc.xul
index 9b327b9c98b..6d3db53c02c 100644
--- a/extensions/xml-rpc/test/xml-rpc.xul
+++ b/extensions/xml-rpc/test/xml-rpc.xul
@@ -30,7 +30,7 @@ function callAsync() {
var Listener = {
onResult: function(client, ctxt, result) {
- result = result.QueryInterface(Components.interfaces.nsISupportsString);
+ result = result.QueryInterface(Components.interfaces.nsISupportsCString);
document.getElementById('statename').setAttribute('value', result.data);
},
diff --git a/extensions/xmlextras/base/public/nsIXMLHttpRequest.idl b/extensions/xmlextras/base/public/nsIXMLHttpRequest.idl
index e43a22a6271..ea5fb98ec9b 100644
--- a/extensions/xmlextras/base/public/nsIXMLHttpRequest.idl
+++ b/extensions/xmlextras/base/public/nsIXMLHttpRequest.idl
@@ -194,7 +194,7 @@ interface nsIXMLHttpRequest : nsISupports {
* returns only after the response has been received.
*
* @param body Either an instance of nsIDOMDocument, nsIInputStream
- * or a string (nsISupportsWString in the native calling
+ * or a string (nsISupportsString in the native calling
* case). This is used to populate the body of the
* HTTP request if the HTTP request method is "POST".
* If the parameter is a nsIDOMDocument, it is serialized.
diff --git a/extensions/xmlextras/base/src/nsXMLHttpRequest.cpp b/extensions/xmlextras/base/src/nsXMLHttpRequest.cpp
index 943f7f9d89b..8ce58571789 100644
--- a/extensions/xmlextras/base/src/nsXMLHttpRequest.cpp
+++ b/extensions/xmlextras/base/src/nsXMLHttpRequest.cpp
@@ -1057,8 +1057,8 @@ nsXMLHttpRequest::Send(nsIVariant *aBody)
if (NS_FAILED(rv))
return NS_ERROR_FAILURE;
} else {
- // nsISupportsWString?
- nsCOMPtr wstr(do_QueryInterface(supports));
+ // nsISupportsString?
+ nsCOMPtr wstr(do_QueryInterface(supports));
if (wstr) {
wstr->GetData(getter_Copies(serial));
} else {
diff --git a/extensions/xmlextras/tests/404post.html b/extensions/xmlextras/tests/404post.html
index b889b0c33b7..4912ff9c4db 100644
--- a/extensions/xmlextras/tests/404post.html
+++ b/extensions/xmlextras/tests/404post.html
@@ -15,7 +15,7 @@ pre {
}
diff --git a/extensions/python/xpcom/test/test_isupports_primitives.py b/extensions/python/xpcom/test/test_isupports_primitives.py
index 3eff19e49c0..6d609d76bf6 100644
--- a/extensions/python/xpcom/test/test_isupports_primitives.py
+++ b/extensions/python/xpcom/test/test_isupports_primitives.py
@@ -17,7 +17,7 @@
# Test our support for the interfaces defined in nsISupportsPrimitives.idl
#
# The framework supports nsISupportsString and nsISupportsWString, but
# only if our class doesnt provide explicit support.
from xpcom import components
@@ -32,7 +32,7 @@ class ImplicitSupportsString:
return ""
class ExplicitSupportsString:
- _com_interfaces_ = [components.interfaces.nsISupports, components.interfaces.nsISupportsString]
+ _com_interfaces_ = [components.interfaces.nsISupports, components.interfaces.nsISupportsCString]
# __str__ will be ignored by XPCOM, as we have _explicit_ support.
def __str__(self):
return ""
@@ -17,7 +17,7 @@
# Test our support for the interfaces defined in nsISupportsPrimitives.idl
#
-# The framework supports nsISupportsString and nsISupportsWString, but
+# The framework supports nsISupportsCString and nsISupportsString, but
# only if our class doesnt provide explicit support.
from xpcom import components